@@ -30,7 +30,7 @@ void Daemon::set_config() {
 
     gps->config(setting->value("interval",1800).toInt(),
                 setting->value("wait",30).toInt(),
-                setting->value("usegps",false).toBool());
+                setting->value("method","cell").toString());
 }
 
 void Daemon::daemon_ok() {
