@@ -1,9 +1,9 @@
 #ifndef DAEMON_H
 #define DAEMON_H
 
-#include <QObject>
-#include "glatitude.h"
+#include <QtCore>
 #include "gps.h"
+#include "glatitude.h"
 
 class Daemon : public QObject {
     Q_OBJECT
@@ -13,14 +13,14 @@ public:
 
 private slots:
     void set();
-    void daemon_OK();
-    void daemon_ERROR();
+    void set_config();
+    void daemon_ok();
+    void daemon_error();
 
 private:
-    GoogleLatitude *glatitude;
-    GpsMaemo5 *gps;
     QSettings *setting;
-
+    GpsMaemo5 *gps;
+    GoogleLatitude *glatitude;
 };
 
 #endif // DAEMON_H
