@@ -1,43 +1,37 @@
 #ifndef GLATITUDE_H
 #define GLATITUDE_H
 
+#include <QtCore>
 #include <QtNetwork>
 
 class GoogleLatitude : public QObject {
     Q_OBJECT
 
 signals:
-    void OK();
-    void ERROR();
+    void glat_ok();
+    void glat_error();
 
 public:
     GoogleLatitude(QObject *parent = 0);
-    void login(QString username, QString password);
-    void set(double la, double lo, double ac=1000.);
-    void freq(int f=120);
+    void set_login(QString username, QString password);
+    void update(double la, double lo, double ac);
     void reset();
-    double get_lat() { return latitude; }
-    double get_lon() { return longitude; }
-    double get_acc() { return accuracy; }
 
 private slots:
-    void finishedreply(QNetworkReply *r);
+    void glat_reply(QNetworkReply *r);
 
 private:
-    // info
     QString user;
     QString pass;
+    bool login_error;
     double latitude;
     double longitude;
     double accuracy;
-    int interval;
-    // stuff
+
     QNetworkAccessManager *worker;
     QUrl urllogin;
     QUrl urldologin;
     QUrl urlupdate;
-    unsigned int lastupdate;
-    bool login_error;
 };
 
 #endif // GLATITUDE_H
