@@ -2,6 +2,7 @@
 #define GPS_H
 
 #include <QtCore>
+#include <QtNetwork>
 
 #ifdef Q_WS_MAEMO_5
 extern "C" {
@@ -28,7 +29,7 @@ public slots:
     void refresh();
     void stop();
     void forcestop();
-    int config(int i, int w, bool g);
+    int config(int i, int w, QString m);
 
 private slots:
 #ifdef Q_WS_MAEMO_5
@@ -43,7 +44,7 @@ private:
     double accuracy;
     int interval;
     int wait;
-    bool usegps;
+    QString method;
     bool emitfix;
     bool stopgps;
 #ifdef Q_WS_MAEMO_5
