@@ -32,8 +32,10 @@ private slots:
     void save_pass(QString _pass) { setting->setValue("pass", _pass); }
     void save_interval(QString _inter) { setting->setValue("interval", _inter.toInt()); }
     void save_wait(QString _wait) { setting->setValue("wait", _wait.toInt()); }
-    void save_gps(int _c) { setting->setValue("usegps", (_c == Qt::Checked ? true : false)); }
     void save_daemon(int _c) { setting->setValue("daemon", (_c == Qt::Checked ? true : false)); }
+    void save_gps_cell() { setting->setValue("method", "cell"); }
+    void save_gps_both() { setting->setValue("method", "both"); }
+    void save_gps_agps() { setting->setValue("method", "agps"); }
 
 private:
     QSettings *setting;
