@@ -6,8 +6,17 @@ int main(int argc, char *argv[]) {
     QCoreApplication::setApplicationName("GoogleLatitude");
 
     QCoreApplication app(argc, argv);
-    Daemon *demonio;
-    demonio = new Daemon();
+
+    if ( app.arguments().contains(QString("--init")) ) {
+        QSettings set;
+        if ( ! set.value("daemon",false).toBool() ) {
+            qDebug() << "No Daemon mode enable";
+            return 0;
+        }
+    }
+
+    Daemon demonio;
+    Q_UNUSED(demonio);
 
     return app.exec();
 }
